from __future__ import print_function, division, absolute_import

import os
import queue

import ddddocr
from fontTools.ttLib import TTFont
from reportlab.graphics import renderPM
from reportlab.graphics.shapes import Group, Drawing
from reportlab.graphics.shapes import Path

from ddddocr_woff.ReportLabPen import ReportLabPen


class anAlySis(object):
    def __init__(self, fontName, imagePath='images', fmt="png"):
        isExists = os.path.exists(imagePath)
        if not isExists:
            print('储存图片目录未指定并且不存在，自动创建')
            os.makedirs(imagePath)

        self.fontName = fontName
        self.imagePath = imagePath
        self.fmt = fmt
        self.font = TTFont(self.fontName)
        self.gs = self.font.getGlyphSet()

    def ttfToImage(self, transmit: queue.Queue):

        glyphNames = self.font.getGlyphOrder()

        for i in glyphNames:
            transmit.put(i)

    def text_ocr(self, transmit: queue.Queue):
        Dict = {}
        while True:
            i = transmit.get()
            if transmit.qsize() != 0:
                if i[0] == '.':  # 跳过'.notdef', '.null'
                    continue
                g = self.gs[i]
                pen = ReportLabPen(self.gs, Path())
                g.draw(pen)
                self.g = Group(pen.path)
                d = Drawing(1000, 1000)
                d.add(self.g)
                self.imageFile = self.imagePath + "/" + i + ".png"
                renderPM.drawToFile(d, self.imageFile, self.fmt)

                with open(self.imageFile, 'rb') as f:
                    png = f.read()
                ocr = ddddocr.DdddOcr()
                res = ocr.classification(png)  # png为图片路径

                Dict[i] = res
            else:
                return Dict

    def run(self):

        self.transmit = queue.Queue()
        self.ttfToImage(self.transmit)

        result = self.text_ocr(self.transmit)
        return result






from fontTools.pens.basePen import BasePen
from reportlab.graphics.shapes import Path

class ReportLabPen(BasePen):
    """A pen for drawing onto a reportlab.graphics.shapes.Path object."""

    def __init__(self, glyphSet, path=None):
        BasePen.__init__(self, glyphSet)
        if path is None:
            path = Path()
        self.path = path

    def _moveTo(self, p):
        (x, y) = p
        self.path.moveTo(x, y)

    def _lineTo(self, p):
        (x, y) = p
        self.path.lineTo(x, y)

    def _curveToOne(self, p1, p2, p3):
        (x1, y1) = p1
        (x2, y2) = p2
        (x3, y3) = p3
        self.path.curveTo(x1, y1, x2, y2, x3, y3)

    def _closePath(self):
        self.path.closePath()



import setuptools

setuptools.setup(
    name="ddddocr_woff",
    version="0.0.2",
    author="Fan&MuYiSen",
    descripyion="基于ddddocr的字体文件一键识别，适用于小白",
    long_description="基于ddddocr的字体文件一键识别，适用于小白",
    long_description_content_type="text/markdown",
    url="",
    packages=setuptools.find_packages(where='.', exclude=(), include=('*',)),
    classifiers=["Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",],
    python_requires='<3.10',

)